@@ -1,5 +1,4 @@
-from __future__ import absolute_import
-# Copyright (c) 2010-2016 openpyxl
+# Copyright (c) 2010-2023 openpyxl
 
 # Simplified implementation of headers and footers: let worksheets have separate items
 
@@ -17,14 +16,14 @@ from openpyxl.descriptors import (
 )
 from openpyxl.descriptors.serialisable import Serialisable
 
-from openpyxl.compat import unicode
+
 from openpyxl.xml.functions import Element
 from openpyxl.utils.escape import escape, unescape
 
 
 FONT_PATTERN = '&"(?P<font>.+)"'
 COLOR_PATTERN  = "&K(?P<color>[A-F0-9]{6})"
-SIZE_REGEX = r"&(?P<size>\d+)"
+SIZE_REGEX = r"&(?P<size>\d+\s?)"
 FORMAT_REGEX = re.compile("{0}|{1}|{2}".format(FONT_PATTERN, COLOR_PATTERN,
                                                SIZE_REGEX)
                           )
@@ -106,7 +105,7 @@ class _HeaderFooterPart(Strict):
         if self.font:
             fmt.append(u'&"{0}"'.format(self.font))
         if self.size:
-            fmt.append("&{0}".format(self.size))
+            fmt.append("&{0} ".format(self.size))
         if self.color:
             fmt.append("&K{0}".format(self.color))
         return u"".join(fmt + [self.text])
@@ -114,7 +113,6 @@ class _HeaderFooterPart(Strict):
     def __bool__(self):
         return bool(self.text)
 
-    __nonzero__ = __bool__
 
 
     @classmethod
@@ -181,7 +179,7 @@ class HeaderFooterItem(Strict):
         for key, part in zip(
             self.__keys, [self.left, self.center, self.right]):
             if part.text is not None:
-                txt.append(u"&{0}{1}".format(key, unicode(part)))
+                txt.append(u"&{0}{1}".format(key, str(part)))
         txt = "".join(txt)
         txt = SUBS_REGEX.sub(replace, txt)
         return escape(txt)
@@ -190,7 +188,6 @@ class HeaderFooterItem(Strict):
     def __bool__(self):
         return any([self.left, self.center, self.right])
 
-    __nonzero__ = __bool__
 
 
     def to_tree(self, tagname):
@@ -198,7 +195,7 @@ class HeaderFooterItem(Strict):
         Return as XML node
         """
         el = Element(tagname)
-        el.text = unicode(self)
+        el.text = str(self)
         return el
 
 
@@ -271,4 +268,3 @@ class HeaderFooter(Serialisable):
         parts = [getattr(self, attr) for attr in self.__attrs__ + self.__elements__]
         return any(parts)
 
-    __nonzero__ = __bool__
